==> huaweicloudsdkvpc-3.0.71-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/add_vpc_extend_cidr_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddVpcExtendCidrResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'vpc': 'Vpc',
        'request_id': 'str'
    }

    attribute_map = {
        'vpc': 'vpc',
        'request_id': 'request_id'
    }

    def __init__(self, vpc=None, request_id=None):
        """AddVpcExtendCidrResponse - a model defined in huaweicloud sdk"""
        
        super(AddVpcExtendCidrResponse, self).__init__()

        self._vpc = None
        self._request_id = None
        self.discriminator = None

        if vpc is not None:
            self.vpc = vpc
        if request_id is not None:
            self.request_id = request_id

    @property
    def vpc(self):
        """Gets the vpc of this AddVpcExtendCidrResponse.


        :return: The vpc of this AddVpcExtendCidrResponse.
        :rtype: Vpc
        """
        return self._vpc

    @vpc.setter
    def vpc(self, vpc):
        """Sets the vpc of this AddVpcExtendCidrResponse.


        :param vpc: The vpc of this AddVpcExtendCidrResponse.
        :type: Vpc
        """
        self._vpc = vpc

    @property
    def request_id(self):
        """Gets the request_id of this AddVpcExtendCidrResponse.

        请求ID

        :return: The request_id of this AddVpcExtendCidrResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AddVpcExtendCidrResponse.

        请求ID

        :param request_id: The request_id of this AddVpcExtendCidrResponse.
        :type: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddVpcExtendCidrResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.0.100-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/add_vpc_extend_cidr_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AddVpcExtendCidrResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'vpc': 'Vpc',
        'request_id': 'str'
    }

    attribute_map = {
        'vpc': 'vpc',
        'request_id': 'request_id'
    }

    def __init__(self, vpc=None, request_id=None):
        """AddVpcExtendCidrResponse

        The model defined in huaweicloud sdk

        :param vpc: 
        :type vpc: :class:`huaweicloudsdkvpc.v3.Vpc`
        :param request_id: 请求ID
        :type request_id: str
        """
        
        super(AddVpcExtendCidrResponse, self).__init__()

        self._vpc = None
        self._request_id = None
        self.discriminator = None

        if vpc is not None:
            self.vpc = vpc
        if request_id is not None:
            self.request_id = request_id

    @property
    def vpc(self):
        """Gets the vpc of this AddVpcExtendCidrResponse.


        :return: The vpc of this AddVpcExtendCidrResponse.
        :rtype: :class:`huaweicloudsdkvpc.v3.Vpc`
        """
        return self._vpc

    @vpc.setter
    def vpc(self, vpc):
        """Sets the vpc of this AddVpcExtendCidrResponse.


        :param vpc: The vpc of this AddVpcExtendCidrResponse.
        :type vpc: :class:`huaweicloudsdkvpc.v3.Vpc`
        """
        self._vpc = vpc

    @property
    def request_id(self):
        """Gets the request_id of this AddVpcExtendCidrResponse.

        请求ID

        :return: The request_id of this AddVpcExtendCidrResponse.
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AddVpcExtendCidrResponse.

        请求ID

        :param request_id: The request_id of this AddVpcExtendCidrResponse.
        :type request_id: str
        """
        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddVpcExtendCidrResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
